@@ -52,8 +52,8 @@ def openUserImg(img):
 def weaponAdd(weaponRes,characters,lvlName):
     if characters.detail.artifact_name_set != "":
         return None
-    WeaponBg = WeaponBgTeampleOne.copy()
-    WeaponBgUp = WeaponBgUpTeampleOne.copy()
+    WeaponBg = openFile.WeaponBgTeampleOne.copy()
+    WeaponBgUp = openFile.WeaponBgUpTeampleOne.copy()
     proc = False    
     d = ImageDraw.Draw(WeaponBg)
     name = characters.detail.name
@@ -94,7 +94,7 @@ def weaponAdd(weaponRes,characters,lvlName):
     weaponRes.put_nowait(WeaponBg)
 
 def nameBanner(nameRes,characters,person,lvlName):
-    NameBg = NameBgTeampleOne.copy()
+    NameBg = openFile.NameBgTeampleOne.copy()
     d = ImageDraw.Draw(NameBg)
     centrName,fonts = centrText(characters.name, witshRam = 220, razmer = 33,start = 2)
     d.text((centrName,28), characters.name, font = fonts, fill=coloring) 
@@ -119,7 +119,7 @@ def stats(statRes,characters,assets):
                 if cout == 3:
                     break
     postion = (26,37)
-    AttributeBg = AttributeBgTeampleOne.copy()
+    AttributeBg = openFile.AttributeBgTeampleOne.copy()
     for key in reversed(list(g)):
         if key[1].value == 0:
             continue
@@ -134,7 +134,7 @@ def stats(statRes,characters,assets):
         iconImg = getIconAdd(key[0])
         if not iconImg:
             continue
-        Attribute = AttributeTeampleOne.copy()
+        Attribute = openFile.AttributeTeampleOne.copy()
         d = ImageDraw.Draw(Attribute)
         
         txt = assets.get_hash_map(key[0])
@@ -152,7 +152,7 @@ def stats(statRes,characters,assets):
 
         AttributeBg.paste(Attribute,(postion[0],postion[1]),Attribute)
         
-        dopValueBg = AttributeDopValueTeampleOne.copy()
+        dopValueBg = openFile.AttributeDopValueTeampleOne.copy()
         dv = ImageDraw.Draw(dopValueBg)
         if key[0] in dopStatAtribute:
             dopStatVal  = dopVal[dopStatAtribute[key[0]]]
@@ -168,8 +168,8 @@ def stats(statRes,characters,assets):
 def constant(rezConstant,characters,person):
     constantRes = []  
     for key in characters.constellations:
-        closeConstBg = ClossedBg.copy()
-        closeConsticon = Clossed.copy()
+        closeConstBg = openFile.ClossedBg.copy()
+        closeConsticon = openFile.Clossed.copy()
         openConstBg = openImageElementConstant(person.element.value)  
         imageIcon = imgD(link = key.icon.url).resize((43,48))
         if not key.unlocked:
@@ -197,10 +197,10 @@ def talants(talatsRes,characters):
     tallantsRes = []
     for key in characters.skills:
         if key.level > 9:
-            talantsBg = TalantsFrameGoldLvlTeampleOne.copy()
+            talantsBg = openFile.TalantsFrameGoldLvlTeampleOne.copy()
         else:
-            talantsBg = TalantsFrameTeampleOne.copy()
-        talantsCount = TalantsCountTeampleOne.copy()
+            talantsBg = openFile.TalantsFrameTeampleOne.copy()
+        talantsCount = openFile.TalantsCountTeampleOne.copy()
         d = ImageDraw.Draw(talantsCount)
         imagesIconTalants = imgD(link = key.icon.url).resize((50,50))
         talantsBg.paste(imagesIconTalants, (8,7),imagesIconTalants)
@@ -217,7 +217,7 @@ def naborArtifact(info,ArtifactNameBg,rezArtSet):
     naborAll = []
     for key in info:
         if info[key] > 1:
-            ArtifactNameFrame = ArtifactNameFrameTeampleOne.copy()
+            ArtifactNameFrame = openFile.ArtifactNameFrameTeampleOne.copy()
             d = ImageDraw.Draw(ArtifactNameFrame)
             centrName,fonts = centrText(key, witshRam = 240, razmer = 15, start = 4, Yram = 24, y = 1) 
             d.text(centrName, str(key), font= fonts, fill=coloring)
@@ -333,7 +333,7 @@ def addArtifact(frameArtifact,artifacRes):
     return frameArtifact
 
 def signature(hide,uid):
-    SignatureText = SignatureOne.copy()
+    SignatureText = openFile.SignatureOne.copy()
     d = ImageDraw.Draw(SignatureText)
 
     if not hide:
